ChainBlock

Struct ChainBlock 

pub struct ChainBlock {
    block: BlockRef,
}
Behavior for chain blocks (iron chain, waxed copper chains).

Chains have an axis property that is set based on which face was clicked during placement, and can be waterlogged.

Fields

block: BlockRef

Implementations

Source

impl ChainBlock

pub const fn new(block: BlockRef) -> Self

Creates a new chain block behavior for the given block.